slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDGetProblemType

Gets the problem type from the SVD object.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDGetProblemType(SVD svd,SVDProblemType *type)

Not Collective

### Input Parameter

| svd | - the singular value solver context

### Output Parameter

| type | - the problem type

### See Also

SVDSetProblemType(), SVDProblemType

### Level

intermediate

### Location

src/svd/interface/svdopts.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages